@@ -5,6 +5,10 @@
 #include <QtNetwork/QNetworkReply>
 #include <QtXml/QDomDocument>
 
+#define VER1_(x) #x
+#define VER_(x)	VER1_(x)
+#define VER VER_(MYVERSION)
+
 Score::Score(const QString &position, const QString &gamer, const QString &score, const QString &level, const QString &date)
 {
     m_position = position;
@@ -87,6 +91,7 @@ void HiScoreModel::getGlobalTop20()
 {
     QUrl url("http://www.piggz.co.uk/spaceinvadersadmin.php");
     url.addQueryItem("action", "getglobaltop20");
+    url.addQueryItem("version", VER);
 
     QNetworkRequest request(url);
     m_networkManager->get(request);
