@@ -19,6 +19,9 @@ int main(int argc, char *argv[])
     QApplication app(argc, argv);
 
     qmlRegisterType<Bunker>("SpaceInvaders", 1, 0, "Bunker");
+    QCoreApplication::setOrganizationName("PGZ");
+    QCoreApplication::setOrganizationDomain("piggz.co.uk");
+    QCoreApplication::setApplicationName("pgz-spaceinvaders");
 
     QmlApplicationViewer viewer;
     HiScores hiscores;
